@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "26-May-23"
+#define SND_DATE "3-July-23"
 #ifndef SND_VERSION
-#define SND_VERSION "23.4"
+#define SND_VERSION "23.5"
 #endif
 #define SND_MAJOR_VERSION "23"
-#define SND_MINOR_VERSION "4"
+#define SND_MINOR_VERSION "5"
 
 #endif
